.. RNAlysis documentation master file, created by
   sphinx-quickstart on Thu Jul  4 20:06:55 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

RNAlysis |release| documentation
===================================

.. image:: https://raw.githubusercontent.com/GuyTeichman/RNAlysis/master/docs/source/logo.png
    :target: https://guyteichman.github.io/RNAlysis
    :width: 400
    :alt: logo


**Useful links:** `Documentation <https://guyteichman.github.io/RNAlysis>`_ |
`Source code <https://github.com/GuyTeichman/RNAlysis>`_ |
`Bug reports <https://github.com/GuyTeichman/RNAlysis/issues>`_ | |pipimage| | |versionssupported| | |githubactions| | |coveralls| | |downloads|

----

.. toctree::
   :maxdepth: 2
   :caption: About RNAlysis:

   What is RNAlysis? <readme>
   GitHub page <https://github.com/GuyTeichman/RNAlysis>
   authors


.. toctree::
   :maxdepth: 2
   :caption: Starting with RNAlysis:

   installation
   user_guide
   glossary

.. toctree::
   :maxdepth: 2
   :caption: Change history:

   history

Modules:
---------
.. autosummary::
  :toctree:
  :caption: Modules:

  rnalysis.filtering
  rnalysis.enrichment
  rnalysis.general


.. toctree::
   :maxdepth: 1
   :caption: Indices and tables:

   genindex
   api_reference


.. |pipimage| image:: https://img.shields.io/pypi/v/rnalysis.svg
    :target: https://pypi.python.org/pypi/rnalysis
    :alt: PyPI version
.. |downloads| image:: https://pepy.tech/badge/rnalysis
    :target: https://pepy.tech/project/rnalysis
    :alt: downloads
.. |versionssupported| image:: https://img.shields.io/pypi/pyversions/RNAlysis.svg
    :target: https://pypi.python.org/pypi/rnalysis
    :alt: Python versions supported

..  |githubactions| image:: https://github.com/guyteichman/RNAlysis/actions/workflows/python-package.yml/badge.svg
    :target: https://github.com/GuyTeichman/RNAlysis/actions/workflows/python-package.yml
    :alt: Build status

..  |coveralls| image:: https://coveralls.io/repos/github/GuyTeichman/RNAlysis/badge.svg
    :target: https://coveralls.io/github/GuyTeichman/RNAlysis?branch=master
    :alt: Coverage
